/*******************************************************************/ /**
* @file benchmark_functions.h
*
* @brief Set of functions for benchmarking optimization algorithms
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.8 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

#ifndef BENCHMARK_FUNCTIONS_H
#define BENCHMARK_FUNCTIONS_H

#include <irafm/math.h>

namespace irafm {

real dejong1(Vector x);

real rastrigin(Vector x);

real schwefel(Vector x);

real ackley(Vector x);

real rosen(Vector x);

real griewank(Vector x);

/// Wrapper for function
class FunctionObject {
public:
   virtual real operator()(const Vector x) abstract;
};

class DeJong1Function: public FunctionObject {
public:
   real operator()(const Vector x) {
      return dejong1(x);
   }
};

class RastriginFunction: public FunctionObject {
public:
   real operator()(const Vector x) {
      return rastrigin(x);
   }
};

class SchwefelFunction: public FunctionObject {
public:
   real operator()(const Vector x) {
      return schwefel(x);
   }
};

class AckleyFunction: public FunctionObject  {
public:
   real operator()(const Vector x) {
      return ackley(x);
   }
};

class RosenFunction: public FunctionObject  {
public:
   real operator()(const Vector x) {
      return rosen(x);
   }
};

class GriewankFunction: public FunctionObject  {
public:
   real operator()(const Vector x) {
      return griewank(x);
   }
};
}

#endif // BENCHMARK_FUNCTIONS_H

// $Log: benchmark_functions.h,v $
// Revision 1.8  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.7  2009/04/30 09:06:46  victor
// + Griewang, Rosen (Radka)
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.6  2009/04/21 12:19:02  victor
// # Renamed quadratic function to dejong1
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.5  2009/04/07 08:43:00  victor
// Astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.4  2008/01/28 11:04:05  victor
// Documenting the source code
//
// Revision 1.3  2007/12/13 13:47:30  victor
// + ackley function
// # simplifying benchmark functions using vector arithmetics
//
// Revision 1.2  2007/11/26 14:20:33  victor
// + Function Object wrappers for benchmark functions
//
// Revision 1.1  2007/11/22 14:51:35  victor
// Initial revision
//
