/*******************************************************************/ /**
* @file crossover.h
*
* @brief definition of classes providing crossover
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.4 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

#ifndef CROSSOVER_H
#define CROSSOVER_H

#include "member_generator.h"

namespace irafm {

class Crossover {
public:
   /// method for crossing of two vectors according to DE Algorithm
   virtual Vector cross(Vector u, Vector x) abstract;

   /// @return symbolic description of mutation method
   virtual std::string getName() abstract;
};

typedef yasper::ptr<Crossover> ptrCrossover;

class BinomialCrossover: public Crossover {
public:
   /// constructor
   BinomialCrossover(real CR): CR(CR) {}

   virtual Vector cross(Vector u, Vector x);
   virtual std::string getName();

protected:
   real CR;
};

class ExponentialCrossover: public Crossover {
public:
   /// constructor
   ExponentialCrossover(real CR): CR(CR) {}

   virtual Vector cross(Vector u, Vector x);
   virtual std::string getName();

   static real findCR(real p, size_t dim);

protected:
   real CR;
};

}

#endif // CROSSOVER_H

// $Log: crossover.h,v $
// Revision 1.4  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.3  2009/01/08 12:23:48  victor
// + Groups of exponential competitive DE algorithms
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.2  2008/12/17 13:46:53  victor
// + Exponential crossover
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.1  2008/12/17 12:51:37  victor
// # Changed structure of DE member generator
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
