/*******************************************************************/ /**
* @file de_algorithm.cpp
*
* @brief Specific algorithm implementation based on DE Algorithm
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.5 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

#include "de_algorithm.h"

namespace irafm {

void DEAlgorithm::computeNewPopulation() {
   Population newGeneration;

   // go through all members of the population
   for (index_t i = 0; i < population_.size(); ++i) {
      // select member
      ptrPopulationMember x = population_.getMember(i);

      // generate new member by cross over with mutant
      ptrPopulationMember newMember;
      newMember = memberGenerator_->generateNewMember(problem_, population_, x);

      // add better member to new generation
      bool success = newMember < x;
      newMember = success ? newMember : x;
      newGeneration.addMember(newMember);

#ifdef DEBUG
      std::cout << newMember->objectiveFunction() << std::endl;
#endif

      // report successfulness of generation back to th generator
      memberGenerator_->reportSuccess(success);
   }

   // replace old population by newly generated one
   population_ = newGeneration;
}

}

// $Log: de_algorithm.cpp,v $
// Revision 1.5  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.4  2008/01/28 11:04:05  victor
// Documenting the source code
//
// Revision 1.3  2007/12/04 15:03:22  victor
// + DEBUG information for testing
//
// Revision 1.2  2007/11/21 09:06:37  victor
// # Removing dependency on Problem from MemberGenerator constructors
//
// Revision 1.1  2007/11/19 15:13:29  victor
// Initial revision
//
