/*******************************************************************/ /**
* @file de_algorithm.h
*
* @brief Specific algorithm implementation based on DE Algorithm
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.7 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

#ifndef DE_ALGORITHM_H
#define DE_ALGORITHM_H

#include "algorithm.h"
#include "member_generator.h"

namespace irafm {

/// Specific algorithm implementation based on DE Algorithm
class DEAlgorithm : public Algorithm {
public:
   /// constructor
   DEAlgorithm(
      ptrMemberGenerator memberGenerator,
      size_t maxIterations = 10000, real minPrecision = 0.000001):
         Algorithm("Differential Evolution",
                   memberGenerator, maxIterations, minPrecision) {}

   /// destructor
   virtual ~DEAlgorithm() {}

   virtual void computeNewPopulation();

protected:

private:
};

}

#endif // DE_ALGORITHM_H

// $Log: de_algorithm.h,v $
// Revision 1.7  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.6  2009/04/07 08:43:00  victor
// Astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.5  2008/01/28 11:04:05  victor
// Documenting the source code
//
// Revision 1.4  2007/11/26 12:15:09  victor
// + Algorithm given a name for identification in reports
//
// Revision 1.3  2007/11/21 09:36:15  victor
// + Constructor params
//
// Revision 1.2  2007/11/20 11:56:10  victor
// Refactorings: memberGenerator_ moved to upper class
//
// Revision 1.1  2007/11/19 15:13:29  victor
// Initial revision
//
