/*******************************************************************/ /**
* @file differential_evolution_generator.h
*
* @brief Abstract new member generator according to DE Algorithm
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.2 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

#ifndef DE_MEMBER_GENERATOR_H
#define DE_MEMBER_GENERATOR_H

#include "member_generator.h"
#include "mutation.h"
#include "crossover.h"

namespace irafm {

class DEMemberGenerator: public MemberGenerator {
public:
   /// constructor
   DEMemberGenerator(ptrMutation mutator, ptrCrossover crossover):
         mutator(mutator), crossover(crossover) {}

   /// destructor
   virtual ~DEMemberGenerator() {}

   /// generates candidate vector for new member refered to member x
   virtual Vector generateDEPoint(ptrPopulationMember x, Population &population);

   /// generates candidate vector for new member refered to randomly selected member
   virtual Vector generateTrialPoint(ptrProblem problem, Population &population);

   /// complete generating method for new member creation
   virtual ptrPopulationMember generateNewMember(
      ptrProblem problem, Population &population, ptrPopulationMember member);

   virtual std::string getName();

protected:
   /// Generates new mutant
   ptrMutation mutator;

   /// crosses two members
   ptrCrossover crossover;

private:
};

}

#endif // DE_MEMBER_GENERATOR_H

// $Log: de_member_generator.h,v $
// Revision 1.2  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.1  2008/12/17 12:51:37  victor
// # Changed structure of DE member generator
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
