/*******************************************************************/ /**
* @file member_generator.cpp
*
* @brief Partial implementation of common methods for member generation
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.7 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

#include "member_generator.h"

namespace irafm {

ptrPopulationMember MemberGenerator::generateNewMember(
   ptrProblem problem, Population &population
) {
   Vector trialPoint(problem->dimension());

   do {
      trialPoint = generateTrialPoint(problem, population);
   }
   while (!problem->isInSearchSpace(trialPoint));

   return problem->newMember(trialPoint);
}

ptrPopulationMember MemberGenerator::generateNewMember(ptrProblem problem,
      Population &population, ptrPopulationMember member
                                                      ) {
   // implicitly ignore given member
   return generateNewMember(problem, population);
}

}

// $Log: member_generator.cpp,v $
// Revision 1.7  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.6  2009/04/07 08:43:00  victor
// Astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.5  2008/01/28 11:04:05  victor
// Documenting the source code
//
// Revision 1.4  2007/11/21 09:06:37  victor
// # Removing dependency on Problem from MemberGenerator constructors
//
// Revision 1.3  2007/11/19 15:14:25  victor
// Added Differential Evolution Algorithm
//
// Revision 1.2  2007/11/15 08:50:47  victor
// Generalizing method for creating new member for checking vector bounds
//
// Revision 1.1  2007/11/14 13:37:18  victor
// Initial revision of EA lib
//
