/*******************************************************************/ /**
* @file member_generator.h
*
* @brief Contains abstract class providing creation of new member
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.10 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

#ifndef MEMBER_GENERATOR_H
#define MEMBER_GENERATOR_H

#include "problem.h"

namespace irafm {

/// Abstract class providing creation of new member
class MemberGenerator {
public:
   /// constructor
   MemberGenerator() {};

   /// destructor
   virtual ~MemberGenerator() {};

   /// generate new trial point from given population
   virtual Vector generateTrialPoint(
      ptrProblem problem, Population &population) abstract;

   /// generate new trial member from given population
   virtual ptrPopulationMember generateNewMember(
      ptrProblem problem, Population &population);

   /// generate new trial member from given population and one member
   virtual ptrPopulationMember generateNewMember(ptrProblem problem,
         Population &population, ptrPopulationMember member);

   /// feedback - reporting success of the last generated member
   void reportSuccess(const bool success = true) pure;

   /// name of the generator, may contain parameters
   virtual std::string getName() abstract;

protected:

private:
};

/// smart pointer to MemberGenerator
typedef yasper::ptr<MemberGenerator> ptrMemberGenerator;

}

#endif // MEMBER_GENERATOR_H

// $Log: member_generator.h,v $
// Revision 1.10  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.9  2008/12/17 12:51:37  victor
// # Changed structure of DE member generator
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.8  2008/11/23 15:06:30  victor
// Working on ProblemStudy and ProblemReporter
//
// Revision 1.7  2008/01/28 11:04:05  victor
// Documenting the source code
//
// Revision 1.6  2007/11/26 12:33:44  victor
// + Member Generator given a name for identification in reports
//
// Revision 1.5  2007/11/21 09:06:37  victor
// # Removing dependency on Problem from MemberGenerator constructors
//
// Revision 1.4  2007/11/19 15:14:25  victor
// Added Differential Evolution Algorithm
//
// Revision 1.3  2007/11/19 11:29:39  victor
// Added Competitive Member Generator
//
// Revision 1.2  2007/11/15 08:50:47  victor
// Generalizing method for creating new member for checking vector bounds
//
// Revision 1.1  2007/11/14 13:37:18  victor
// Initial revision of EA lib
//
