/*******************************************************************/ /**
* @file mutation.h
*
* @brief implementation of classes providing mutation
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.4 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

// STL
#include <sstream>

#include "mutation.h"

namespace irafm {

Vector BestMutation::generateMutant(Population &population) {
   ptrPopulationMember xMin = population.best(rsRemove);

   ptrPopulationMember r1 = population.randomSelect(rsRemove);
   ptrPopulationMember r2 = population.randomSelect(rsRemove);
   ptrPopulationMember r3 = population.randomSelect(rsRemove);
   ptrPopulationMember r4 = population.randomSelect(rsRemove);

   population.addMember(xMin);
   population.addMember(r1);
   population.addMember(r2);
   population.addMember(r3);
   population.addMember(r4);

   Vector u = xMin->data + this->F * (r1->data + r2->data - r3->data - r4->data);

   return u;
}

std::string BestMutation::getName() {
   std::ostringstream result;

   result << "best[F: " << this->F << "]";

   return result.str();
}

Vector RandMutation::generateMutant(Population &population) {
   ptrPopulationMember r1 = population.randomSelect(rsRemove);
   ptrPopulationMember r2 = population.randomSelect(rsRemove);
   ptrPopulationMember r3 = population.randomSelect(rsRemove);

   population.addMember(r1);
   population.addMember(r2);
   population.addMember(r3);

   Vector u = r1->data + this->F * (r2->data - r3->data);

   return u;
}

std::string RandMutation::getName() {
   std::ostringstream result;

   result << "rand[F: " << this->F << "]";

   return result.str();
}

Vector Rand_RL_Mutation::generateMutant(Population &population) {
   Population selection = population.randomSelect(3, rsLeave);

   ptrPopulationMember r1 = selection.getMember(0, rsLeave);
   ptrPopulationMember r2 = selection.getMember(1, rsLeave);
   ptrPopulationMember r3 = selection.getMember(2, rsLeave);

   Vector u = r1->data + this->F * (r2->data - r3->data);

   return u;
}

std::string Rand_RL_Mutation::getName() {
   std::ostringstream result;

   result << "rand_rl[F: " << this->F << "]";

   return result.str();
}

}

// $Log: mutation.cpp,v $
// Revision 1.4  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.3  2009/04/07 08:43:00  victor
// Astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.2  2009/03/27 19:36:58  victor
// Satisfying linux compatibility
//
// Revision 1.1  2008/12/17 12:51:37  victor
// # Changed structure of DE member generator
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
