/*******************************************************************/ /**
* @file mutation.h
*
* @brief declaration of classes providing mutation
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.2 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

#ifndef MUTATION_H
#define MUTATION_H

#include "member_generator.h"

namespace irafm {

class Mutation {
public:
   /// method for generating mutant vector
   virtual Vector generateMutant(Population &population) abstract;

   /// @return symbolic description of mutation method
   virtual std::string getName() abstract;
};

typedef yasper::ptr<Mutation> ptrMutation;

class BestMutation: public Mutation {
public:
   /// constructor
   BestMutation(real F): F(F) {}

   /// method for generating mutant vector
   virtual Vector generateMutant(Population &population);

   virtual std::string getName();

protected:
   real F; ///< parameter influencing behavior of mutation
};

class RandMutation: public Mutation {
public:
   /// constructor
   RandMutation(real F): F(F) {}

   /// method for generating mutant vector
   virtual Vector generateMutant(Population &population);

   virtual std::string getName();

protected:
   real F; ///< parameter influencing behavior of mutation
};

class Rand_RL_Mutation: public Mutation {
public:
   /// constructor
   Rand_RL_Mutation(real F): F(F) {}

   /// method for generating mutant vector
   virtual Vector generateMutant(Population &population);

   virtual std::string getName();

protected:
   real F; ///< parameter influencing behavior of mutation
};

}

#endif // MUTATION_H

// $Log: mutation.h,v $
// Revision 1.2  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.1  2008/12/17 12:51:37  victor
// # Changed structure of DE member generator
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
