/*******************************************************************/ /**
* @file population_member.cpp
*
* @brief Implementation of population member
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.5 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

// STL
#include <sstream>

#include "population_member.h"

namespace irafm {

using namespace std;

size_t PopulationMember::numCalls_ = 0;;

string PopulationMember::print() {
   ostringstream ss;
   ss << "[(";

   for (index_t i = 0; i < data.size(); i++) {
      ss << data[i];

      if (i < data.size() - 1) {
         ss << ", ";
      }
   }

   ss << "): " << criteria() << + "]";

   return ss.str();
}

real PopulationMember::objectiveFunction() {
   if (flCached) return cachedValue;

   flCached = true;
   ++numCalls_;
   cachedValue = criteria();

   return cachedValue;
}

void PopulationMember::resetCounter() {
   numCalls_ = 0;
}

size_t PopulationMember::numberOfCalls() {
   return numCalls_;
}

bool operator<(ptrPopulationMember m1, ptrPopulationMember m2) {
   return m1->objectiveFunction() < m2->objectiveFunction();
}

bool operator<=(ptrPopulationMember m1, ptrPopulationMember m2) {
   return m1->objectiveFunction() <= m2->objectiveFunction();
}

}

// $Log: population_member.cpp,v $
// Revision 1.5  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.4  2009/04/07 08:43:00  victor
// Astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.3  2008/01/28 11:04:05  victor
// Documenting the source code
//
// Revision 1.2  2007/11/21 09:05:28  victor
// + Counting evaluation of objective function
// + Caching value of objective function
//
// Revision 1.1  2007/11/14 13:37:18  victor
// Initial revision of EA lib
//
