/*******************************************************************/ /**
* @file simplex_generator.cpp
*
* @brief Specific member generator according to Simplex method
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.7 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

// STL
#include <sstream>

#include "simplex_generator.h"

// IRAFM
#include <irafm/math.h>

namespace irafm {

using namespace math;

real SimplexGenerator::U() {
   Interval paramInterval(s_, alpha_ - s_);

   return paramInterval.randomValue();
}

Vector SimplexGenerator::generateTrialPoint(
   ptrProblem problem, Population &population
) {
   Population selection;
   selection = population.randomSelect(problem->dimension() + 1, rsLeave);

   // get and remove worst member
   Vector x = selection.worst(rsRemove)->data;

   // compute centroid of remaining members
   Vector g = centroid(selection);

   // compute weighted reflection of x around centroid g
   Vector y = g + U() * (g - x);

   return y;
}

std::string SimplexGenerator::getName() {
   std::ostringstream result;

   result << "Simplex Generator [" << "s: " << s_ << ", alpha: " << alpha_ << "]";

   return result.str();
}

}

// $Log: simplex_generator.cpp,v $
// Revision 1.7  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.6  2009/04/07 08:43:00  victor
// Astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.5  2008/01/28 11:04:05  victor
// Documenting the source code
//
// Revision 1.4  2007/11/26 12:33:44  victor
// + Member Generator given a name for identification in reports
//
// Revision 1.3  2007/11/21 09:06:37  victor
// # Removing dependency on Problem from MemberGenerator constructors
//
// Revision 1.2  2007/11/15 08:50:47  victor
// Generalizing method for creating new member for checking vector bounds
//
// Revision 1.1  2007/11/14 13:37:18  victor
// Initial revision of EA lib
//
