/*******************************************************************/ /**
* @file simplex_generator.h
*
* @brief Specific member generator according to Simplex method
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.8 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

#ifndef SIMPLEX_GENERATOR_H
#define SIMPLEX_GENERATOR_H

#include "member_generator.h"

namespace irafm {

/// Member generator according to Simplex method
class SimplexGenerator : public MemberGenerator {
public:
   /// constructor
   SimplexGenerator(real s, real alpha): s_(s), alpha_(alpha) {}

   /// destructor
   virtual ~SimplexGenerator() {};

   virtual Vector generateTrialPoint(ptrProblem problem, Population &population);

   virtual std::string getName();

protected:
   /// parameters determining behavior of simplex reflection
   real s_;
   real alpha_;

   /// computes parameter U for reflection around centroid
   real U();

private:
};

}

#endif // SIMPLEX_GENERATOR_H

// $Log: simplex_generator.h,v $
// Revision 1.8  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.7  2009/04/07 08:43:00  victor
// Astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.6  2008/01/28 11:04:05  victor
// Documenting the source code
//
// Revision 1.5  2007/11/26 12:33:44  victor
// + Member Generator given a name for identification in reports
//
// Revision 1.4  2007/11/21 09:06:37  victor
// # Removing dependency on Problem from MemberGenerator constructors
//
// Revision 1.3  2007/11/15 08:50:47  victor
// Generalizing method for creating new member for checking vector bounds
//
// Revision 1.2  2007/11/14 13:49:36  victor
// * Refatorization for usage of SimplexGenerator
//
// Revision 1.1  2007/11/14 13:37:18  victor
// Initial revision of EA lib
//
