/*******************************************************************/ /**
* @file worst_member_substitution.cpp
*
* @brief Specific algorithm skelet replacing the worst population member
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.5 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

#include "worst_member_substitution.h"

#define MAX_STABLE_ITERATIONS 100

namespace irafm {

void WorstMemberSubstitution::computeNewPopulation() {
   int iteration = 0;
   bool populationChanged = false;

   while ((!populationChanged) && (iteration < MAX_STABLE_ITERATIONS)) {
      ++iteration;
      ptrPopulationMember newMember;
      newMember = memberGenerator_->generateNewMember(problem_, population_);

      if (!problem_->isInSearchSpace(newMember->data))
         continue;

      populationChanged = population_.replaceWorst(newMember);
   }

}

}

// $Log: worst_member_substitution.cpp,v $
// Revision 1.5  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.4  2009/04/07 08:43:00  victor
// Astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.3  2008/01/28 11:04:05  victor
// Documenting the source code
//
// Revision 1.2  2007/11/21 09:06:37  victor
// # Removing dependency on Problem from MemberGenerator constructors
//
// Revision 1.1  2007/11/20 11:56:58  victor
// Initial revision
//
