/*******************************************************************/ /**
* @file worst_member_substitution.h
*
* @brief Specific algorithm skelet replacing the worst population member
*
* @author Viktor PAVLISKA, Hashim HABIBALLA, Jiri BLAZEK
*
* @par Copyright  2007 IRAFM
*   Institute for Research and Application of Fuzzy Modeling           @n
*   University of Ostrava                                              @n
*   30. dubna 22                                                       @n
*   701 03, Ostrava 1                                                  @n
*   Czech Republic                                                     @n
*
*   This file is part of The Stochastic Algorithms for Global
*   Optimization C++ library.
*
*   This library is free software which you can redistribute and/or
*   modify under the terms of the GNU Library General Public License
*   version 3.
*
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty
*   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*   See the GNU General Public License for more details.
*
*   You should have received a copy of the GNU Library General Public
*   License along with this library.  If not, write to the Free Software
*   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*
* $Revision: 1.5 $
* $Date: 2010/03/23 10:07:49 $
************************************************************************/

#ifndef WORST_MEMBER_SUBSTITUTION_H
#define WORST_MEMBER_SUBSTITUTION_H

#include "algorithm.h"

namespace irafm {

/// Specific algorithm skelet replacing the worst population member
class WorstMemberSubstitution : public Algorithm {
public:
   /// constructor with default parameter values
   WorstMemberSubstitution(
      ptrMemberGenerator memberGenerator,
      size_t maxIterations = 10000, real minPrecision = 0.000001):
         Algorithm("Worst Member Substitution",
                   memberGenerator, maxIterations, minPrecision) {}

   /// destructor
   virtual ~WorstMemberSubstitution() {};

   virtual void computeNewPopulation();

protected:

private:
};

}

#endif // WORST_MEMBER_SUBSTITUTION_H

// $Log: worst_member_substitution.h,v $
// Revision 1.5  2010/03/23 10:07:49  victor
// removing namespace
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.4  2009/04/07 08:43:00  victor
// Astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.3  2008/01/28 11:04:05  victor
// Documenting the source code
//
// Revision 1.2  2007/11/26 12:15:09  victor
// + Algorithm given a name for identification in reports
//
// Revision 1.1  2007/11/20 12:06:09  victor
// Initial revision
//
