// STL
#include <stdexcept>

#include "domain_box.h"

namespace irafm {

namespace math {

void DomainBox::addDimension(Interval bounds) {
   intervals_.push_back(bounds);
}

bool DomainBox::containsVector(Vector v) const {
   if (dimension() != v.size())
      throw std::domain_error("Vector has different dimension.");

   for (index_t i = 0; i < dimension(); ++i) {
      if (!intervals_[i].contains(v[i]))
         return false;
   }

   return true;
}

Vector DomainBox::bound(Vector v) const {
   if (dimension() != v.size())
      throw std::domain_error("Vector has different dimension.");

   Vector result(v);

   for (index_t i = 0; i < dimension(); ++i) {
      result[i] = intervals_[i].bound(v[i]);
   }

   return result;
}

Vector DomainBox::randomVector() const {
   Vector result(dimension());

   for (index_t i = 0; i < dimension(); ++i) {
      result[i] = intervals_[i].randomValue();
   }

   return result;
}

}

}

// $Log: domain_box.cpp,v $
// Revision 1.5  2010/03/23 14:28:19  victor
// astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.4  2009/04/07 08:43:00  victor
// Astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.3  2007/12/04 14:53:08  victor
// + vector bounding
//
// Revision 1.2  2007/11/14 13:31:26  victor
// + Added const directive
//
// Revision 1.1  2007/11/07 12:53:15  victor
// Preparing box domain - multi interval for EA
//
