// STL
#include <cstdlib>

#include "functions.h"

namespace irafm {

namespace math {

/**
* @return arithmetic average of numbers a and b
*/
real avg(const real &a, const real &b) {
   return (a + b) / 2;
}

/**
* Linear mapping value from interval <a; b> into <u; v>
*
* value a is mapped into u, value b into v, center of interval <a; b>
* is mapped into center of interval <u; v> and so on...
*
* @return transformed value
*/
real linear_map(const real &value,
                const real &a, const real &b, const real &u, const real &v) {
   real result = u + ((value - a) / (b - a)) * (v - u);

   return result;
}

/**
* @brief Bounds value x into interval <a; b>
*
* for x from interval <a; b> returns unchanged x
* when x is less than a, returns a
* when x is greater than b, returns b
*/
real bound(const real &a, const real &x, const real &b) {
   if (x < a)
      return a;

   if (x > b)
      return b;

   return x;
}

unsigned long int random(long int maxRandomValue) {
   return rand() % maxRandomValue;
}

} // namespace math

} // namespace irafm

// $Log: functions.cpp,v $
// Revision 1.4  2010/03/23 14:28:19  victor
// astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.3  2009/04/07 08:43:00  victor
// Astyle reformat
// Committed on the Free edition of March Hare Software CVSNT Server.
// Upgrade to CVS Suite for more features and support:
// http://march-hare.com/cvsnt/
//
// Revision 1.2  2007/11/15 15:36:18  victor
// + random(max)
//
// Revision 1.1  2007/04/05 14:14:25  Viktor
// Initial revision
//
